==> providence-core-1.7.0-sources.jar: net/morimekta/providence/descriptor/PStructDescriptor.java <==
/*
 * Copyright 2015-2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.descriptor;

import net.morimekta.providence.PMessage;
import net.morimekta.providence.PMessageBuilder;
import net.morimekta.providence.PMessageVariant;

import javax.annotation.Nonnull;
import java.util.function.Supplier;

/**
 * The definition of a thrift structure.
 */
public abstract class PStructDescriptor<T extends PMessage<T, F>, F extends PField> extends PMessageDescriptor<T, F> {
    public PStructDescriptor(String programName,
                             String name,
                             Supplier<PMessageBuilder<T, F>> builderSupplier,
                             boolean simple) {
        super(programName, name, builderSupplier, simple);
    }

    @Nonnull
    @Override
    public PMessageVariant getVariant() {
        return PMessageVariant.STRUCT;
    }
}

==> providence-core-2.7.0-sources.jar: net/morimekta/providence/descriptor/PStructDescriptor.java <==
/*
 * Copyright 2015-2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.descriptor;

import net.morimekta.providence.PMessage;
import net.morimekta.providence.PMessageBuilder;
import net.morimekta.providence.PMessageVariant;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.util.function.Supplier;

/**
 * The definition of a thrift structure.
 */
@Immutable
public abstract class PStructDescriptor<T extends PMessage<T>> extends PMessageDescriptor<T> {
    public PStructDescriptor(String programName,
                             String name,
                             Supplier<PMessageBuilder<T>> builderSupplier,
                             boolean simple) {
        super(programName, name, builderSupplier, simple);
    }

    @Nonnull
    @Override
    public PMessageVariant getVariant() {
        return PMessageVariant.STRUCT;
    }
}
